@@ -21,7 +21,8 @@
  
 #define NUM_KEY_MODIFIERS 3
 // ISO_Level3_Shift = AltGr
-char *key_modifiers[] = { NULL, "Shift_L", "ISO_Level3_Shift" };
+char *key_modifiers[] = { NULL, "Mode_switch", "ISO_Level3_Shift" };
+char *shift_key = "Shift_L";
  
 #define MAX_KEYSYM 65536
 // this maps what keysyms need a modifier pushed
